@@ -587,7 +587,7 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
                     if (!isNull(controls) && !isNull(gridLayout)) {
                         row = gridLayout.rowCount();
                         var localTitle = title;
-                        if (propertyTypeId.isCustom() && group!==RSettings.getAppId()) {
+                        if (propertyTypeId.isCustom() && group!==RSettings.getAppId() && propertyTypeId.getCustomPropertyTitle()!=="Attributes") {
                             var pos = title.indexOf("_");
                             if (pos!==-1) {
                                 localTitle = title.mid(pos+1);
@@ -597,6 +597,11 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
                             localTitle = RSettings.translate("REntity", title);
                         }
 
+                        var l = attributes.getLabel();
+                        if (l.length>0) {
+                            localTitle = l;
+                        }
+
                         var label = new QLabel(localTitle + this.colon, groupBox);
                         label.textInteractionFlags = Qt.TextSelectableByMouse;
                         label.alignment = Qt.AlignRight | Qt.AlignVCenter;
@@ -760,20 +765,27 @@ PropertyEditorImpl.prototype.initControls = function(propertyTypeId, onlyChanges
     if (propertyTypeId.getId()===RTextEntity.PropertyHAlign.getId()) {
         controls = this.initChoiceControls(
                     objectName, propertyTypeId, onlyChanges, control, false, true);
-//                    [ qsTr("Left"), qsTr("Center"), qsTr("Right"),
-//                      qsTr("Aligned"), qsTr("Middle"), qsTr("Fit")],
-//                    [ RS.HAlignLeft, RS.HAlignCenter, RS.HAlignRight,
-//                      RS.HAlignAlign, RS.HAlignMid, RS.HAlignFit]);
     }
 
     // Vertical alignment: combo box:
     else if (propertyTypeId.getId()===RTextEntity.PropertyVAlign.getId()) {
         controls = this.initChoiceControls(
                     objectName, propertyTypeId, onlyChanges, control, false, true);
-//                    [qsTr("Top"), qsTr("Middle"), qsTr("Base"), qsTr("Bottom")],
-//                    [RS.VAlignTop, RS.VAlignMiddle, RS.VAlignBase, RS.VAlignBottom]);
     }
 
+    // Polyline orientation: combo box:
+    else if (propertyTypeId.getId()===RPolylineEntity.PropertyOrientation.getId()) {
+        controls = this.initChoiceControls(
+                    objectName, propertyTypeId, onlyChanges, control, false, true);
+    }
+
+    // Arc dimension arc symbol type: combo box:
+    else if (propertyTypeId.getId()===RDimArcLengthEntity.PropertyDimArcSymbolType.getId()) {
+        controls = this.initChoiceControls(
+                    objectName, propertyTypeId, onlyChanges, control, false, true);
+    }
+
+
     // Hatch pattern: combo box with hatch names:
     else if (propertyTypeId.getId()===RHatchEntity.PropertyPatternName.getId()) {
         var patternNames = undefined;
@@ -1108,6 +1120,12 @@ PropertyEditorImpl.prototype.initChoiceControls = function(
     else if (propertyTypeId.getId()===RTextEntity.PropertyVAlign.getId()) {
         WidgetFactory.initVAlignCombo(control);
     }
+    else if (propertyTypeId.getId()===RPolylineEntity.PropertyOrientation.getId()) {
+        WidgetFactory.initOrientationCombo(control);
+    }
+    else if (propertyTypeId.getId()===RDimArcLengthEntity.PropertyDimArcSymbolType.getId()) {
+        WidgetFactory.initArcSymbolTypeCombo(control);
+    }
     else if (isOfType(control, QComboBox) /*&& propertyTypeId.getId()!==REntity.PropertyLayer.getId()*/) {
         control.clear();
         if (isNull(choices)) {
